==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klik på bakkeikonet
eller tryk på genvejen igen, for at stoppe optagelse</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Optag</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Skærmoptagelse</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Gem mislykkedes. Gem den venligst i din hjemmemappe.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Skærmbilledet er færdigt</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>markeringsområde</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gemt til %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Optagelse færdig</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gemt til %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Optag</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Skærmoptagelse starter om %1 sekunder</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Skriv teksten her</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/skærmbillede</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Afslut/gem</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Tegning</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Justering af størrelse</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Hurtig start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Vinduesskærmbillede</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Forsink skærmbillede</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Fuldt skærmbillede</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Blyant</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Højere øverst</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Højere nederst</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Bredere til venstre</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Bredere til højre</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Lavere øverst</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Lavere nederst</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Lavere til venstre</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Lavere til højre</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Start optagelse</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Sløring</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Lyd til</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Systemlyd</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Lyd fra</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Vis tastetryk</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Skjul tastetryk</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam til</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam fra</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Vis klik</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Blyant</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Gem til</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Optagelser</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klik på bakkeikonet
eller tryk på genvejen igen, for at stoppe optagelse</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Optag</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Skærmoptagelse</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Gem mislykkedes. Gem den venligst i din hjemmemappe.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Skærmbilledet er færdigt</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>markeringsområde</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gemt til %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Optagelse færdig</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gemt til %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Optag</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Skærmoptagelse starter om %1 sekunder</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Skriv teksten her</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/skærmbillede</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Afslut/gem</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Justering af størrelse</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Hurtig start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Vinduesskærmbillede</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Forsink skærmbillede</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Fuldt skærmbillede</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Blyant</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Højere øverst</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Højere nederst</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Bredere til venstre</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Bredere til højre</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Lavere øverst</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Lavere nederst</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Lavere til venstre</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Lavere til højre</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Start optagelse</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Sløring</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Lyd til</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Systemlyd</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Lyd fra</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Vis tastetryk</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Skjul tastetryk</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam til</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam fra</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Vis klik</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Blyant</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Gem til</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Afslut</translation>
    </message>
</context>
</TS>
